@@ -106,8 +106,6 @@ public abstract class AbstractAdvertisementConfigService implements Advertisemen
     private static final String SQL_DELETE_MAPPING = "DELETE FROM advertisement_mapping where configId=?;";
     private static final String SQL_SELECT_MAPPING_SIMPLE = "Select configId from advertisement_mapping where reseller=? AND package=?;";
     private static final String SQL_SELECT_CONFIG = "Select config from advertisement_config where configId=?;";
-    protected static final String PACKAGE_ALL = "default";
-    protected static final String RESELLER_ALL = "default";
     private static final String PREVIEW_CONFIG = "com.openexchange.advertisement.preview";
 
     /**
@@ -536,9 +534,9 @@ public abstract class AbstractAdvertisementConfigService implements Advertisemen
     @Override
     public List<ConfigResult> setConfig(String reseller, Map<String, String> configs) throws OXException {
         List<ConfigResult> resultList = new ArrayList<>();
-        for (String pack : configs.keySet()) {
+        for (Map.Entry<String, String> entry : configs.entrySet()) {
             try {
-                ConfigResultType status = setConfigInternal(reseller, pack, configs.get(pack));
+                ConfigResultType status = setConfigInternal(reseller, entry.getKey(), entry.getValue());
                 resultList.add(new ConfigResult(status, null));
             } catch (OXException e) {
                 resultList.add(new ConfigResult(ConfigResultType.ERROR, e));
